from main import bmybit

class Strategy():

    def getStrategy(self, id):
        try:
            bmybit.get('/strategies',
                        params={'id': id})
        except:
            print 'Could not get strategy'

    def getStrategies(self):
        try:
            bmybit.get('/strategies')
        except:
            print 'Could not get strategies'

    def startStrategy(self, exchange, pair, currency, amout, level, risk, lockin):
        try:
            bmybit.get('/strategies/start',
                        params={'exchange':   exchange,
                              'pair':       pair,
                              'currency':   currency,
                              'condition':  amount,
			      'level':      level,
			      'risk':       risk,
			      'lockin':     lockin})
        except:
            print 'Could not start the strategy'

    def terminateStrategy():
        try:
            bmybit.get('/strategies/terminate',
                        params={'id': id})
        except:
            print 'Could not terminate the strategy'



from main import bmybit

class Account():

    def balance(self, exchange, pair):
	try:
    	    bmybit.get('/accounts/balance',
 			params={'exchange': exchange,
				'pair':pair})
	except:
    	    print 'Could not get account balance'

    def info(self):
        try:
            bmybit.get('/accounts/info')
        except:
            print 'Could not get account info'






from main import bmybit

class Exchange():

    def createOrder(self, exchange, pair, currency, amount):
        try:
	    # should be a post request !!
            bmybit.get('/exchanges/order',
                        params={'exchange':   exchange,
                              'pair':       pair,
                              'currency':   currency,
                              'condition':  amount})
        except:
            print 'Could not create the order'


    def getExchange(self, id):
        try:
            bmybit.get('/exchanges',
                        params={'id': id})
        except:
            print 'Could not get exchange'

    def getExchanges():
        try:
            bmybit.get('/exchanges')
        except:
            print 'Could not get exchange list'



import hmac
import hashlib
import requests
import config

API_KEY = config.API_KEY
API_SECRET = config.API_SECRET

api_sign = hmac.new(API_SECRET, '/api/v1/strategies?id=1', hashlib.sha256).hexdigest()


from account import Account
from alarm import Alarm
from strategy import Strategy

compte = Account()
alarm  = Alarm()
strategy = Strategy()
strategy.getStrategies()

#alarm.create('BTC-USD',1,1,'<')
#compte.balance('BTC-USD',1)





import hmac
import config
import hashlib
import requests
import tortilla

API_KEY    = config.API_KEY
API_SECRET = config.API_SECRET
API_URL    = config.API_URL


api_sign = hmac.new(API_SECRET, '/api/v1/strategies', hashlib.sha256).hexdigest()

'''
response = requests.get(
  'https://test.bmybit.com/api/v1/strategies',
  headers={
    'X-Api-Key': API_KEY,
    'X-Api-Sign': api_sign
  },
)

print response.content
'''


bmybit = tortilla.wrap('https://test.bmybit.com/api/v1')

bmybit.config.headers['X-Api-Key'] = API_KEY
bmybit.config.headers['api_sign']  = api_sign

print bmybit.config.headers

res = bmybit.get('strategies',params = {'id':330},  headers={
    'X-Api-Key': API_KEY,
    'X-Api-Sign': api_sign
  })

print res




from setuptools import setup

setup(name='bmywp',
      version='0.1',
      description='BymBit Rest API wrapper',
      url='https://github.com/abdesslem/bmywp',
      author='Abdesslem Amri',
      author_email='amriabdesslem@gmail.com',
      license='GPLv3.0',
      packages=['bmywp'],
      zip_safe=False)



from main import bmybit

class Alarm():

    def create(self, exchange, pair, price, condition):
        try:
            bmybit.post('/alarms',
                        data={'exchange':   exchange,
                              'pair':       pair,
			      'price':      price,
			      'condition':  condition})
        except:
            print 'Could not create alarm'

    def get(self, exchange=None, pair=None):
        try:
            bmybit.get('/alarms',
                        params={'exchange': exchange,
                                'pair':pair})
        except:
            print 'Could not get alarms'


